# JAX_CRPS
Autodifferentiable implementation of the Continous Rank Probability Score CRPS in JAX.


## 📦 Installation

To install this package locally in editable mode:

```bash
git clone https://github.com/username/JAX_CRPS.git
cd JAX_CRPS
pip install -e .
```

This installs the JAX_CRPS package and its dependencies. The -e (editable) flag lets you modify the code without reinstalling.

You can then import the package in Python:

from JAX_CRPS.crps import jax_crps


# my_package

This is a simple example Python package.

## Installation

```bash
pip install .